@@ -1,6 +1,6 @@
 import logging
 from abc import ABC, abstractmethod
-from typing import Optional
+from typing import Dict, Optional, Union
 
 from httpx import Response
 
@@ -17,18 +17,25 @@ class BaseCheckBoxClient(ABC):
         self,
         base_url: str = BASE_API_URL,
         requests_timeout: int = DEFAULT_REQUEST_TIMEOUT,
+        proxy: Optional[Union[str, Dict[str, str]]] = None,
+        verify_ssl: bool = True,
         api_version: str = API_VERSION,
         storage: Optional[SessionStorage] = None,
     ) -> None:
         self.base_url = base_url
         self.api_version = api_version
         self.timeout = requests_timeout
+        self.proxy = proxy
+        self.verify_ssl = verify_ssl
         self.storage = storage or SessionStorage()
 
     @abstractmethod
     def emit(self, storage: SessionStorage, method: AbstractMethod):
         pass
 
+    def __call__(self, *args, **kwargs):
+        return self.emit(*args, **kwargs)
+
     @classmethod
     def _check_response(cls, response: Response):
         if response.status_code >= 500:
@@ -39,3 +46,11 @@ class BaseCheckBoxClient(ABC):
             raise CheckBoxAPIValidationError(status=response.status_code, content=response.json())
         if response.status_code >= 400:
             raise CheckBoxAPIError(status=response.status_code, content=response.json())
+
+    def _set_license_key(
+        self, storage: Optional[SessionStorage], license_key: Optional[str]
+    ) -> None:
+        if license_key is None:
+            return
+        storage = storage or self.storage
+        storage.license_key = license_key
