@@ -41,3 +41,12 @@ class GetReportVisualization(GetReport):
 
     def parse_response(self, storage: SessionStorage, response: Response):
         return response.content
+
+
+class GetReportVisualizationText(GetReportVisualization):
+    def __init__(self, report_id: str, width: int = 50):
+        super().__init__(report_id=report_id, fmt="text", width=width)
+
+    def parse_response(self, storage: SessionStorage, response: Response):
+        result = super().parse_response(storage=storage, response=response)
+        return result.decode()
